summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMathieu Parent <math.parent@gmail.com>2018-05-04 22:22:46 +0200
committerAndrew Bartlett <abartlet@samba.org>2018-05-12 02:09:27 +0200
commit8ed2873400ffa10ed1abd745faa54a0fa8029a40 (patch)
tree972131ad483e95d1626eb43ed90a7c352511d0be
parent6fa770fd546c87e588d75cc143be2b20f59f5602 (diff)
downloadsamba-8ed2873400ffa10ed1abd745faa54a0fa8029a40.tar.gz
Fix spelling s/propogate/propagate/
Signed-off-by: Mathieu Parent <math.parent@gmail.com> Reviewed-by: Andrew Bartlett <abartlet@samba.org> Reviewed-by: Garming Sam <garming@catalyst.net.nz>
-rw-r--r--ctdb/server/ctdb_ltdb_server.c4
-rw-r--r--source4/dsdb/samdb/ldb_modules/repl_meta_data.c2
-rw-r--r--source4/dsdb/samdb/ldb_modules/util.c2
-rw-r--r--source4/ntvfs/common/opendb_tdb.c2
-rw-r--r--source4/torture/raw/notify.c4
-rw-r--r--source4/torture/smb2/notify.c4
-rwxr-xr-xwintest/test-s4-howto.py12
7 files changed, 15 insertions, 15 deletions
diff --git a/source4/dsdb/samdb/ldb_modules/repl_meta_data.c b/source4/dsdb/samdb/ldb_modules/repl_meta_data.c
index a89a816c869..e739400634c 100644
--- a/source4/dsdb/samdb/ldb_modules/repl_meta_data.c
+++ b/source4/dsdb/samdb/ldb_modules/repl_meta_data.c
@@ -4731,7 +4731,7 @@ static int replmd_make_deleted_child_dn(TALLOC_CTX *tmp_ctx,
their current values. This has the effect of changing these
attributes to have been last updated by the current DC. This is
needed to ensure that renames performed as part of conflict
- resolution are propogated to other DCs
+ resolution are propagated to other DCs
*/
static int replmd_name_modify(struct replmd_replicated_request *ar,
struct ldb_request *req, struct ldb_dn *dn)
diff --git a/source4/dsdb/samdb/ldb_modules/util.c b/source4/dsdb/samdb/ldb_modules/util.c
index 9e37c085bba..738b773611d 100644
--- a/source4/dsdb/samdb/ldb_modules/util.c
+++ b/source4/dsdb/samdb/ldb_modules/util.c
@@ -688,7 +688,7 @@ int dsdb_check_single_valued_link(const struct dsdb_attribute *attr,
place. For example, the recyclebin feature is marked as enabled both
on the CN=Partitions,CN=Configurration object and on the NTDS DN of
each DC in the forest. It seems likely that it is the job of the KCC
- to propogate between the two
+ to propagate between the two
*/
int dsdb_check_optional_feature(struct ldb_module *module, struct GUID op_feature_guid, bool *feature_enabled)
{
diff --git a/source4/ntvfs/common/opendb_tdb.c b/source4/ntvfs/common/opendb_tdb.c
index 2047a0b3145..9fe0b2627ee 100644
--- a/source4/ntvfs/common/opendb_tdb.c
+++ b/source4/ntvfs/common/opendb_tdb.c
@@ -352,7 +352,7 @@ static NTSTATUS odb_tdb_open_can_internal(struct odb_context *odb,
/* a batch oplock caches close calls, which
means the client application might have
already closed the file. We have to allow
- this close to propogate by sending a oplock
+ this close to propagate by sending a oplock
break request and suspending this call
until the break is acknowledged or the file
is closed */
diff --git a/wintest/test-s4-howto.py b/wintest/test-s4-howto.py
index e290b07732d..e8f2111fafa 100755
--- a/wintest/test-s4-howto.py
+++ b/wintest/test-s4-howto.py
@@ -269,12 +269,12 @@ def test_dcpromo(t, vm):
child.expect("CN=Schema,CN=Configuration,${BASEDN}")
child.expect("was successful")
- t.info("Checking if new users propogate to windows")
+ t.info("Checking if new users propagate to windows")
t.retry_cmd('bin/samba-tool user add test2 ${PASSWORD2}', ["created successfully"])
t.retry_cmd("%s -L ${WIN_HOSTNAME}.${LCREALM} -Utest2%%${PASSWORD2} -k no" % (smbclient), ['Sharename', 'Remote IPC'])
t.retry_cmd("%s -L ${WIN_HOSTNAME}.${LCREALM} -Utest2%%${PASSWORD2} -k yes" % (smbclient), ['Sharename', 'Remote IPC'])
- t.info("Checking if new users on windows propogate to samba")
+ t.info("Checking if new users on windows propagate to samba")
child.sendline("net user test3 ${PASSWORD3} /add")
while True:
i = child.expect(["The command completed successfully",
@@ -458,12 +458,12 @@ def test_join_as_dc(t, vm):
child.expect("CN=Configuration,${WIN_BASEDN}")
child.expect("was successful")
- t.info("Checking if new users propogate to windows")
+ t.info("Checking if new users propagate to windows")
t.retry_cmd('bin/samba-tool user add test2 ${PASSWORD2}', ["created successfully"])
t.retry_cmd("%s -L ${WIN_HOSTNAME}.${WIN_REALM} -Utest2%%${PASSWORD2} -k no" % (smbclient), ['Sharename', 'Remote IPC'])
t.retry_cmd("%s -L ${WIN_HOSTNAME}.${WIN_REALM} -Utest2%%${PASSWORD2} -k yes" % (smbclient), ['Sharename', 'Remote IPC'])
- t.info("Checking if new users on windows propogate to samba")
+ t.info("Checking if new users on windows propagate to samba")
child.sendline("net user test3 ${PASSWORD3} /add")
child.expect("The command completed successfully")
t.retry_cmd("%s -L ${HOSTNAME}.${WIN_REALM} -Utest3%%${PASSWORD3} -k no" % (smbclient), ['Sharename', 'IPC'])
@@ -538,14 +538,14 @@ def test_join_as_rodc(t, vm):
ordered=True,
regex=True)
- t.info("Checking if new users on windows propogate to samba")
+ t.info("Checking if new users on windows propagate to samba")
child.sendline("net user test3 ${PASSWORD3} /add")
child.expect("The command completed successfully")
t.retry_cmd("%s -L ${HOSTNAME}.${WIN_REALM} -Utest3%%${PASSWORD3} -k no" % (smbclient), ['Sharename', 'IPC'])
t.retry_cmd("%s -L ${HOSTNAME}.${WIN_REALM} -Utest3%%${PASSWORD3} -k yes" % (smbclient), ['Sharename', 'IPC'])
# should this work?
- t.info("Checking if new users propogate to windows")
+ t.info("Checking if new users propagate to windows")
t.cmd_contains('bin/samba-tool user add test2 ${PASSWORD2}', ['No RID Set DN'])
t.info("Checking propogation of user deletion")
diff --git a/ctdb/server/ctdb_ltdb_server.c b/ctdb/server/ctdb_ltdb_server.c
index c199aac2d1d..d94d942a9fa 100644
--- a/ctdb/server/ctdb_ltdb_server.c
+++ b/ctdb/server/ctdb_ltdb_server.c
@@ -1521,7 +1521,7 @@ int32_t ctdb_ltdb_update_seqnum(struct ctdb_context *ctdb, uint32_t db_id, uint3
}
/*
- timer to check for seqnum changes in a ltdb and propogate them
+ timer to check for seqnum changes in a ltdb and propagate them
*/
static void ctdb_ltdb_seqnum_check(struct tevent_context *ev,
struct tevent_timer *te,
@@ -1531,7 +1531,7 @@ static void ctdb_ltdb_seqnum_check(struct tevent_context *ev,
struct ctdb_context *ctdb = ctdb_db->ctdb;
uint32_t new_seqnum = tdb_get_seqnum(ctdb_db->ltdb->tdb);
if (new_seqnum != ctdb_db->seqnum) {
/* something has changed - propogate it */
TDB_DATA data;
data.dptr = (uint8_t *)&ctdb_db->db_id;
data.dsize = sizeof(uint32_t);
@@ -1531,7 +1531,7 @@ static void ctdb_ltdb_seqnum_check(struct tevent_context *ev,
uint32_t new_seqnum = tdb_get_seqnum(ctdb_db->ltdb->tdb);
if (new_seqnum != ctdb_db->seqnum) {
- /* something has changed - propogate it */
+ /* something has changed - propagate it */
TDB_DATA data;
data.dptr = (uint8_t *)&ctdb_db->db_id;
diff --git a/source4/torture/raw/notify.c b/source4/torture/raw/notify.c
index fdb5771bf3d..afb4a8eb5f2 100644
--- a/source4/torture/raw/notify.c
+++ b/source4/torture/raw/notify.c
@@ -1462,7 +1462,7 @@ static bool test_notify_tree(struct torture_context *tctx,
talloc_free(path);
}
/* give a bit of time for the events to propogate */
tv = timeval_current();
do {
@@ -1485,7 +1485,7 @@ static bool test_notify_tree(struct torture_context *tctx,
}
} while (!all_done && timeval_elapsed(&tv) < 20);
- torture_comment(tctx, "took %.4f seconds to propogate all events\n", timeval_elapsed(&tv));
+ torture_comment(tctx, "took %.4f seconds to propagate all events\n", timeval_elapsed(&tv));
for (i=0;i<ARRAY_SIZE(dirs);i++) {
torture_assert_int_equal_goto(tctx,
@@ -1462,7 +1462,7 @@ static bool test_notify_tree(struct torture_context *tctx,
talloc_free(path);
}
- /* give a bit of time for the events to propogate */
+ /* give a bit of time for the events to propagate */
tv = timeval_current();
do {
diff --git a/source4/torture/smb2/notify.c b/source4/torture/smb2/notify.c
index 6ef24fe889e..d13f1c0506c 100644
--- a/source4/torture/smb2/notify.c
+++ b/source4/torture/smb2/notify.c
@@ -1878,7 +1878,7 @@ static bool torture_smb2_notify_tree(struct torture_context *torture,
talloc_free(path);
}
/* give a bit of time for the events to propogate */
tv = timeval_current();
do {
@@ -1904,7 +1904,7 @@ static bool torture_smb2_notify_tree(struct torture_context *torture,
}
} while (!all_done && timeval_elapsed(&tv) < 20);
- torture_comment(torture, "took %.4f seconds to propogate all events\n",
+ torture_comment(torture, "took %.4f seconds to propagate all events\n",
timeval_elapsed(&tv));
for (i=0;i<ARRAY_SIZE(dirs);i++) {
@@ -1878,7 +1878,7 @@ static bool torture_smb2_notify_tree(struct torture_context *torture,
talloc_free(path);
}
- /* give a bit of time for the events to propogate */
+ /* give a bit of time for the events to propagate */
tv = timeval_current();
do {